==> com_clubmanagement_1.1.zip: admin/views/positions/tmpl/default.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>
<?php
$page = $this->pagination;
$positions=ClubmanagementHelper::getPositions();

#echo "<hr/>";
#print_r($this->items[0]);
#echo "<h1>Palimm</h1>";
#echo "<h2>".__FILE__."</h2>";
#$filter_surname_firstchar = $this->lists["filter_surname_firstchar"];
#print_r($this->lists);

?>
<script type="text/javascript">
jQuery.noConflict();
jQuery(document).ready(function(){
	jQuery("table thead input.calendar").datepicker({dateFormat: 'yy-mm-dd'});
	jQuery("table thead input.calendar").change(function() {
		jQuery("#adminForm").submit();
	});
	jQuery("#deleteDatefilter img").click(function() {
		jQuery("table thead input.calendar").val('');
		jQuery("#adminForm").submit();
	});
});
</script>

<form action="index.php" method="post" name="adminForm" id="adminForm">
	<table class="adminlist">
	<thead>
		<tr>
			<th style="width:10px;"><?php echo JText::_( 'NUM' ); ?></th>
			<th style="width:10px;"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $this->items ); ?>);" /></th>
			<th style="width:30px;"><?php
			$attr = "onchange='this.form.submit();'";
			$filter_state_sex_options = array(
				(object) array("value"=>-1, "text"=>JText::_("COM_CLUBMANAGEMENT_SHOWALL")),
				(object) array("value"=>"f", "text"=>JText::_("COM_CLUBMANAGEMENT_FEMALE")),
				(object) array("value"=>"m", "text"=>JText::_("COM_CLUBMANAGEMENT_MALE")),
			);
			echo JHTML::_('grid.sort',   JText::_('COM_CLUBMANAGEMENT_SEX'), 'sex', @$this->lists['order_Dir'], @$this->lists['order'] );
			echo "<br/>";
			echo JHTML::_('select.genericlist',  $filter_state_sex_options, "filter_state_sex", $attr, "value", "text", $this->lists['filter_state_sex']); 
			?></th>
			<th style="width: 100px; text-align: left;" class="title"><?php 
				echo JHTML::_('grid.sort',   JText::_('COM_CLUBMANAGEMENT_SURNAME'), 'surname', @$this->lists['order_Dir'], @$this->lists['order'] );
				echo "<br/>";
				if (count($firstChars)>0) {
					$blank = new stdClass;
					$blank->text = JText::_("COM_CLUBMANAGEMENT_SHOWALL");
					$blank->value = 0;
					array_unshift($firstChars, $blank);
					$attr = "onchange='this.form.submit();'";
				#	echo JHTML::_('select.genericlist', $firstChars, "filter_surname_firstchar", $attr, "value", "text", $filter_surname_firstchar);
				}
			?></th>
			<th style="width:100px;"><?php echo JHTML::_('grid.sort', JText::_('COM_CLUBMANAGEMENT_NAME'), 'name', @$this->lists['order_Dir'], @$this->lists['order'] ); ?></th>
			<th><?php 
				echo JHTML::_('grid.sort', JText::_('COM_CLUBMANAGEMENT_POSITIONS'), 'positions', @$this->lists['order_Dir'], @$this->lists['order'] );
				echo "<br/>";
				$filter_positions =0;
#				print_r($positions);
				array_unshift($positions, (object) array('value'=>'0', 'text'=>JText::_("COM_CLUBMANAGEMENT_SHOWALL")));
				echo JHTML::_('select.genericlist', $positions, "filter_positions", $attr, "value", "text", $this->lists['filter_positions']);
			?></th>
		</tr>
		<tr>
			<th colspan="6">Datum auswählen <input class="inputbox calendar" type="text" name="filter_byDate" id="filter_byDate" value="<?php echo $this->lists['filter_byDate'];?>"/><span id="deleteDatefilter"><?php echo LegendHelper::renderIcon('delete', FALSE);?></span></th>
		</tr>
	</thead>
	<tfoot>
		<tr>
			<td colspan="6">
				<?php echo $page->getListFooter(); ?>
			</td>
		</tr>
	</tfoot>
	<tbody>
	<?php
	$k = 0;
	LegendHelper::renderIcon("sex_m");
	LegendHelper::renderIcon("sex_f");
	for ($i=0; $i<count( $this->items ); $i++)
	{

		$row = &$this->items[$i];
#print_r($row);
		$published		= FALSE;#JHTML::_('grid.published', $row, $i );
		$checked 	= JHTML::_('grid.id',   $i, $row->people_id );
		$link 		= JRoute::_( 'index.php?option=com_clubmanagement&view=positions&task=edit&cid[]='. $row->people_id );
		
		?>
		<tr class="<?php echo "row".$k; ?>">
			<td><a href="<?php echo $link; ?>"><?php echo $row->people_id; ?></a></td>
			<td><?php echo $checked; ?></td>
			<td><?php echo LegendHelper::renderIcon("sex_".$row->sex);?></td>
			<td><a href="<?php echo $link; ?>"><?php echo $row->surname; ?></a></td>
			<td><a href="<?php echo $link; ?>"><?php echo $row->name; ?></a></td>
			<td><?php echo $row->positions; ?></td>
		</tr>
		<?php
		$k = 1 - $k;
	}
	?>
		<tr>
			<td colspan="14"><?php 
			echo LegendHelper::printIconLegend(); 
			?></td>
		</tr>
	</tbody>
	</table>

<input type="hidden" name="option" value="com_clubmanagement" />
<input type="hidden" name="view" value="positions" />
<input type="hidden" name="task" value="fffff" />
<input type="hidden" name="boxchecked" value="0" />
</form>

==> com_clubmanagement_1.3.zip: admin/views/positions/tmpl/default.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>
<?php
$page = $this->pagination;
//echo "HH";
$positions=array();
//$positions=ClubmanagementHelper::getPositions();

#echo "<hr/>";
#print_r($this->items[0]);
#echo "<h1>Palimm</h1>";
#echo "<h2>".__FILE__."</h2>";
#$filter_surname_firstchar = $this->lists["filter_surname_firstchar"];
#print_r($this->lists);

?>
<script type="text/javascript">
jQuery.noConflict();
jQuery(document).ready(function(){
	jQuery("table thead input.calendar").datepicker({dateFormat: 'yy-mm-dd'});
	jQuery("table thead input.calendar").change(function() {
		jQuery("#adminForm").submit();
	});
	jQuery("#deleteDatefilter img").click(function() {
		jQuery("table thead input.calendar").val('');
		jQuery("#adminForm").submit();
	});
});
</script>

<form action="index.php" method="post" name="adminForm" id="adminForm">
	<table class="adminlist">
	<thead>
		<tr>
			<th style="width:10px;"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $this->items ); ?>);" /></th>
			<th style="width:30px;"><?php
			$attr = "onchange='this.form.submit();'";
			$filter_state_sex_options = array(
				(object) array("value"=>-1, "text"=>JText::_("COM_CLUBMANAGEMENT_SHOWALL")),
				(object) array("value"=>"f", "text"=>JText::_("COM_CLUBMANAGEMENT_FEMALE")),
				(object) array("value"=>"m", "text"=>JText::_("COM_CLUBMANAGEMENT_MALE")),
			);
			echo JHTML::_('grid.sort',   JText::_('COM_CLUBMANAGEMENT_SEX'), 'sex', @$this->lists['order_Dir'], @$this->lists['order'] );
			echo "<br/>";
			echo JHTML::_('select.genericlist',  $filter_state_sex_options, "filter_state_sex", $attr, "value", "text", $this->lists['filter_state_sex']); 
			?></th>
			<th style="width: 100px; text-align: left;" class="title"><?php 
				echo JHTML::_('grid.sort',   JText::_('COM_CLUBMANAGEMENT_SURNAME'), 'surname', @$this->lists['order_Dir'], @$this->lists['order'] );
				echo "<br/>";
				if (count($firstChars)>0) {
					$blank = new stdClass;
					$blank->text = JText::_("COM_CLUBMANAGEMENT_SHOWALL");
					$blank->value = 0;
					array_unshift($firstChars, $blank);
					$attr = "onchange='this.form.submit();'";
				#	echo JHTML::_('select.genericlist', $firstChars, "filter_surname_firstchar", $attr, "value", "text", $filter_surname_firstchar);
				}
			?></th>
			<th style="width:100px;"><?php echo JHTML::_('grid.sort', JText::_('COM_CLUBMANAGEMENT_NAME'), 'name', @$this->lists['order_Dir'], @$this->lists['order'] ); ?></th>
			<th><?php 
				echo JHTML::_('grid.sort', JText::_('COM_CLUBMANAGEMENT_POSITIONS'), 'positions', @$this->lists['order_Dir'], @$this->lists['order'] );
				echo "<br/>";
				$filter_positions =0;
#				print_r($positions);
				array_unshift($positions, (object) array('value'=>'0', 'text'=>JText::_("COM_CLUBMANAGEMENT_SHOWALL")));
				echo JHTML::_('select.genericlist', $positions, "filter_positions", $attr, "value", "text", $this->lists['filter_positions']);
			?></th>
			<th style="width:10px;"><?php echo JText::_( 'NUM' ); ?></th>
		</tr>
		<tr>
			<th colspan="6">Datum auswählen <input class="inputbox calendar" type="text" name="filter_byDate" id="filter_byDate" value="<?php echo $this->lists['filter_byDate'];?>"/><span id="deleteDatefilter"><?php echo LegendHelper::renderIcon('delete', FALSE);?></span></th>
		</tr>
	</thead>
	<tfoot>
		<tr>
			<td colspan="6">
				<?php echo $page->getListFooter(); ?>
			</td>
		</tr>
	</tfoot>
	<tbody>
	<?php
	$k = 0;
	LegendHelper::renderIcon("sex_m");
	LegendHelper::renderIcon("sex_f");
	for ($i=0; $i<count( $this->items ); $i++)
	{

		$row = &$this->items[$i];
#print_r($row);
		$published		= FALSE;#JHTML::_('grid.published', $row, $i );
		$checked 	= JHTML::_('grid.id',   $i, $row->people_id );
		$link 		= JRoute::_( 'index.php?option=com_clubmanagement&view=positions&task=edit&cid[]='. $row->people_id );
		
		?>
		<tr class="<?php echo "row".$k; ?>">
			<td><?php echo $checked; ?></td>
			<td><?php echo LegendHelper::renderIcon("sex_".$row->sex);?></td>
			<td><a href="<?php echo $link; ?>"><?php echo $row->surname; ?></a></td>
			<td><a href="<?php echo $link; ?>"><?php echo $row->name; ?></a></td>
			<td><?php echo $row->positions; ?></td>
			<td><?php echo $row->people_id; ?></td>
		</tr>
		<?php
		$k = 1 - $k;
	}
	?>
		<tr>
			<td colspan="14"><?php 
			echo LegendHelper::printIconLegend(); 
			?></td>
		</tr>
	</tbody>
	</table>

<input type="hidden" name="option" value="com_clubmanagement" />
<input type="hidden" name="view" value="positions" />
<input type="hidden" name="task" value="fffff" />
<input type="hidden" name="boxchecked" value="0" />
</form>
